@@ -125,21 +125,6 @@ describe 'tempest' do
       end
     end
 
-    context 'with sahara_plugins' do
-      let :params do
-        {
-          :configure_images   => false,
-          :configure_networks => false,
-          :sahara_available   => true,
-          :sahara_plugins     => ['vanilla'],
-        }
-      end
-
-      it 'properly configures Sahara plugins in tempest.conf' do
-        is_expected.to contain_tempest_config('data-processing-feature-enabled/plugins').with_value(['vanilla'])
-      end
-    end
-
     context 'with reseller_admin_role' do
       let :params do
         {
@@ -168,26 +153,6 @@ describe 'tempest' do
       end
     end
 
-    context 'with ec2api_available parameter' do
-      let :params do
-        {
-          :configure_images   => false,
-          :configure_networks => false,
-          :ec2api_available   => true,
-        }
-      end
-
-      it 'creates ec2 credentials' do
-        is_expected.to contain_tempest_ec2_credentials('ec2_test_creds').with(
-          :ensure            => 'present',
-          :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
-          :user              => 'ec2api-tester',
-          :project           => 'openstack'
-        )
-      end
-
-    end
-
     context 'with parameters' do
       let :params do
         { :configure_images    => true,
@@ -204,7 +169,6 @@ describe 'tempest' do
         it 'installs packages' do
 
           is_expected.to contain_package('git')
-          is_expected.to contain_package("python3-setuptools")
 
           platform_params[:dev_packages].each do |package|
             is_expected.to contain_package("#{package}")
@@ -212,18 +176,16 @@ describe 'tempest' do
 
           is_expected.to contain_class('tempest::params')
 
-          is_expected.to contain_exec('install-pip').with(
-            :command => 'easy_install pip',
-            :unless  => "which #{platform_params[:pip_command]}",
-            :path    => ['/bin', '/usr/bin', '/usr/local/bin'],
-            :require => "Package[python3-setuptools]"
-          )
+          if platform_params[:pip_package_name]
+            is_expected.to contain_package('pip').with(
+              :name => platform_params[:pip_package_name],
+            )
+          end
 
           is_expected.to contain_exec('install-tox').with(
-            :command => "#{platform_params[:pip_command]} install -U tox",
+            :command => [platform_params[:pip_command], 'install', '-U', 'tox'],
             :unless  => 'which tox',
             :path    => ['/bin', '/usr/bin', '/usr/local/bin'],
-            :require => 'Exec[install-pip]'
           )
 
           is_expected.to contain_vcsrepo('/var/lib/tempest').with(
@@ -249,7 +211,7 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('auth/admin_username').with(:value => nil)
           is_expected.to contain_tempest_config('auth/admin_system').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('auth/tempest_roles').with(:value => '<SERVICE DEFAULT>')
-          is_expected.to contain_tempest_config('auth/use_dynamic_credentials').with(:value => nil)
+          is_expected.to contain_tempest_config('auth/use_dynamic_credentials').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('object-storage/reseller_admin_role').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('compute/flavor_ref').with(:value => nil)
           is_expected.to contain_tempest_config('compute/flavor_ref_alt').with(:value => nil)
@@ -265,13 +227,13 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('volume/build_timeout').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('object-storage/build_timeout').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('compute-feature-enabled/attach_encrypted_volume').with(:value => false)
-          is_expected.to contain_tempest_config('compute-feature-enabled/resize').with(:value => false)
+          is_expected.to contain_tempest_config('compute-feature-enabled/resize').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('validation/image_ssh_user').with(:value => nil)
           is_expected.to contain_tempest_config('validation/image_alt_ssh_user').with(:value => nil)
           is_expected.to contain_tempest_config('validation/run_validation').with(:value => false)
           is_expected.to contain_tempest_config('validation/ssh_key_type').with(:value => '<SERVICE DEFAULT>')
-          is_expected.to contain_tempest_config('identity/admin_role').with(:value => nil)
-          is_expected.to contain_tempest_config('identity/auth_version').with(:value => 'v3')
+          is_expected.to contain_tempest_config('identity/admin_role').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('identity/auth_version').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('identity/alt_password').with(:value => nil)
           is_expected.to contain_tempest_config('identity/alt_password').with_secret( true )
           is_expected.to contain_tempest_config('identity/alt_project_name').with(:value => nil)
@@ -284,18 +246,19 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('identity/username').with(:value => nil)
           is_expected.to contain_tempest_config('identity/project_domain_name').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('identity/user_domain_name').with(:value => '<SERVICE DEFAULT>')
-          is_expected.to contain_tempest_config('identity/uri').with(:value => nil)
-          is_expected.to contain_tempest_config('identity/uri_v3').with(:value => nil)
-          is_expected.to contain_tempest_config('identity/ca_certificates_file').with(:value => nil)
-          is_expected.to contain_tempest_config('identity/disable_ssl_certificate_validation').with(:value => nil)
-          is_expected.to contain_tempest_config('identity-feature-enabled/api_v3').with(:value => true)
+          is_expected.to contain_tempest_config('identity/uri').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('identity/uri_v3').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('identity/ca_certificates_file').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('identity/disable_ssl_certificate_validation').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('identity-feature-enabled/api_v3').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('image-feature-enabled/api_v2').with(:value => '<SERVICE DEFAULT>')
-          is_expected.to contain_tempest_config('l2gw/l2gw_switch').with(:value => nil)
+          is_expected.to contain_tempest_config('l2gw/l2gw_switch').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('network-feature-enabled/api_extensions').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('network/public_network_id').with(:value => nil)
           is_expected.to contain_tempest_config('network/public_router_id').with(:value => nil)
-          is_expected.to contain_tempest_config('dashboard/login_url').with(:value => nil)
-          is_expected.to contain_tempest_config('dashboard/dashboard_url').with(:value => nil)
+          is_expected.to contain_tempest_config('dashboard/login_url').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('dashboard/dashboard_url').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('dashboard/disable_ssl_certificate_validation').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('database/db_flavor_ref').with(:value => nil)
           is_expected.to contain_tempest_config('service_available/cinder').with(:value => true)
           is_expected.to contain_tempest_config('volume-feature-enabled/backup').with(:value => false)
@@ -303,16 +266,13 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('service_available/heat').with(:value => false)
           is_expected.to contain_tempest_config('service_available/ceilometer').with(:value => false)
           is_expected.to contain_tempest_config('service_available/aodh').with(:value => false)
-          is_expected.to contain_tempest_config('service_available/bgpvpn').with(:value => false)
           is_expected.to contain_tempest_config('service_available/gnocchi').with(:value => false)
+          is_expected.to contain_tempest_config('service_available/sg_core').with(:value => false)
           is_expected.to contain_tempest_config('service_available/horizon').with(:value => true)
-          is_expected.to contain_tempest_config('service_available/l2gw').with(:value => false)
           is_expected.to contain_tempest_config('service_available/neutron').with(:value => true)
           is_expected.to contain_tempest_config('service_available/mistral').with(:value => false)
           is_expected.to contain_tempest_config('service_available/vitrage').with(:value => false)
           is_expected.to contain_tempest_config('service_available/nova').with(:value => true)
-          is_expected.to contain_tempest_config('service_available/sahara').with(:value => false)
-          is_expected.to contain_tempest_config('service_available/murano').with(:value => false)
           is_expected.to contain_tempest_config('service_available/swift').with(:value => false)
           is_expected.to contain_tempest_config('service_available/trove').with(:value => false)
           is_expected.to contain_tempest_config('service_available/ironic').with(:value => false)
@@ -323,6 +283,7 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('service_available/octavia').with(:value => false)
           is_expected.to contain_tempest_config('service_available/barbican').with(:value => false)
           is_expected.to contain_tempest_config('service_available/manila').with(:value => false)
+          is_expected.to contain_tempest_config('enforce_scope/barbican').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('enforce_scope/cinder').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('enforce_scope/glance').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('enforce_scope/keystone').with(:value => '<SERVICE DEFAULT>')
@@ -335,13 +296,21 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('enforce_scope/designate').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('enforce_scope/octavia').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('enforce_scope/manila').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('compute/min_microversion').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('compute/max_microversion').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('placement/min_microversion').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('placement/max_microversion').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('volume/min_microversion').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('volume/max_microversion').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('key_manager/min_microversion').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('key_manager/max_microversion').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('baremetal/min_microversion').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('baremetal/max_microversion').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('share/min_api_microversion').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('share/max_api_microversion').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('dns/nameservers').with(:value => '<SERVICE DEFAULT>')
-          is_expected.to contain_tempest_config('aws/ec2_url').with(:value => '<SERVICE DEFAULT>')
-          is_expected.to contain_tempest_config('aws/aws_region').with(:value => '<SERVICE DEFAULT>')
-          is_expected.to contain_tempest_config('aws/image_id').with(:value => nil)
-          is_expected.to contain_tempest_config('aws/ebs_image_id').with(:value => nil)
-          is_expected.to contain_tempest_config('heat_plugin/auth_url').with(:value => nil)
-          is_expected.to contain_tempest_config('heat_plugin/auth_version').with(:value => '3')
+          is_expected.to contain_tempest_config('heat_plugin/auth_url').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('heat_plugin/auth_version').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('heat_plugin/admin_password').with_secret( true )
           is_expected.to contain_tempest_config('heat_plugin/admin_project_name').with(:value => nil)
           is_expected.to contain_tempest_config('heat_plugin/admin_username').with(:value => nil)
@@ -355,8 +324,8 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('heat_plugin/instance_type').with(:value => nil)
           is_expected.to contain_tempest_config('heat_plugin/minimal_image_ref').with(:value => nil)
           is_expected.to contain_tempest_config('heat_plugin/minimal_instance_type').with(:value => nil)
-          is_expected.to contain_tempest_config('baremetal/driver').with(:value => 'fake')
-          is_expected.to contain_tempest_config('baremetal/enabled_hardware_types').with(:value => 'ipmi')
+          is_expected.to contain_tempest_config('baremetal/driver').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('baremetal/enabled_hardware_types').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('load_balancer/member_role').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('load_balancer/admin_role').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('load_balancer/observer_role').with(:value => '<SERVICE DEFAULT>')
@@ -365,19 +334,21 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('share/multitenancy_enabled').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('share/enable_protocols').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('share/multi_backend').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('telemetry_services/metric_backends').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('telemetry_services/alarm_backend').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('share/capability_storage_protocol').with(:value => '<SERVICE DEFAULT>')
-          is_expected.to contain_tempest_config('cli/cli_dir').with(:value => nil)
+          is_expected.to contain_tempest_config('cli/cli_dir').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_oslo__concurrency('tempest_config').with(
             :lock_path => '/var/lib/tempest'
           )
           is_expected.to contain_tempest_config('scenario/img_file').with(:value => '/var/lib/tempest/cirros-0.4.0-x86_64-disk.img')
           is_expected.to contain_tempest_config('scenario/img_disk_format').with(:value => '<SERVICE DEFAULT>')
-          is_expected.to contain_tempest_config('service_broker/run_service_broker_tests').with(:value => false)
+          is_expected.to contain_tempest_config('service_broker/run_service_broker_tests').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_oslo__log('tempest_config').with(
-            :debug => false,
-            :log_file => '<SERVICE DEFAULT>',
-            :use_stderr => true,
-            :use_syslog => false,
+            :debug                         => '<SERVICE DEFAULT>',
+            :log_file                      => '<SERVICE DEFAULT>',
+            :use_stderr                    => true,
+            :use_syslog                    => '<SERVICE DEFAULT>',
             :logging_context_format_string => '<SERVICE DEFAULT>'
           )
 
@@ -416,13 +387,26 @@ describe 'tempest' do
         end
 
         it 'sets up virtualenv for tempest' do
-          is_expected.to contain_exec('setup-venv').with(
-            :command => "virtualenv -p python3 /var/lib/tempest/.venv && /var/lib/tempest/.venv/bin/#{platform_params[:pip_command]} install -U -r requirements.txt",
-            :cwd     => '/var/lib/tempest',
-            :unless  => 'test -d /var/lib/tempest/.venv',
+          is_expected.to contain_exec('create-venv').with(
+            :command => ['virtualenv', '-p', 'python3', '/var/lib/tempest/.venv'],
+            :creates => '/var/lib/tempest/.venv',
             :path    => ['/bin', '/usr/bin', '/usr/local/bin']
           )
         end
+
+        it 'installs tempest into the virtualenv' do
+          is_expected.to contain_exec('install-tempest').with(
+            :command     => [
+              'virtualenv', '-p', 'python3', '/var/lib/tempest/.venv'
+            ],
+            :command     => [
+              "/var/lib/tempest/.venv/bin/#{platform_params[:pip_command]}", 'install',
+              '-U', '-r', 'requirements.txt'
+            ],
+            :cwd         => '/var/lib/tempest',
+            :refreshonly => true,
+          )
+        end
       end
     end
 
@@ -458,10 +442,10 @@ describe 'tempest' do
       end
       it 'creates tempest workspace' do
         is_expected.to contain_exec('tempest-workspace').with(
-          :command     => 'tempest init /var/lib/tempest',
+          :command     => ['tempest', 'init', '/var/lib/tempest'],
           :path        => ['/bin', '/usr/bin'],
           :refreshonly => true,
-          :require     => 'Package[tempest]'
+          :subscribe   => 'Package[tempest]'
         )
       end
     end
@@ -478,7 +462,7 @@ describe 'tempest' do
 
       it 'supports customizes tempest workspace' do
         is_expected.to contain_exec('tempest-workspace').with(
-          :command => 'tempest init /tmp/tempest',
+          :command => ['tempest', 'init', '/tmp/tempest'],
         )
       end
     end
@@ -541,40 +525,34 @@ describe 'tempest' do
 
     context 'with when managing tests packages for keystone (required service)' do
       it "should install keystone tests package" do
-        is_expected.to contain_package('python-keystone-tests')
-        is_expected.to_not contain_package('python-sahara-tests-tempest')
-      end
-    end
-
-    context 'with when managing tests packages for sahara (optional service)' do
-      before :each do
-        params.merge!({ :sahara_available => true })
+        is_expected.to contain_package('python-keystone-tests-tempest').with(
+          :name => platform_params[:python_keystone_tests]
+        )
       end
 
-      it "should install sahara tests package" do
-        if platform_params[:python_sahara_tests]
-          is_expected.to contain_package('python-sahara-tests-tempest')
-        end
-      end
-    end
-
-    context 'with when managing tests packages for neutron (optional service)' do
-      before :each do
-        params.merge!({
-          :neutron_available => true,
-          :public_network_id => '4c423fc6-87f7-4e6d-9d3c-abc13058ae5b'
-        })
+      it "should not install optional heat tests package" do
+        is_expected.to_not contain_package('python-heat-tests-tempest')
       end
 
-      it "should install neutron and *aas tests packages" do
-        if platform_params[:python_neutron_tests]
-          is_expected.to contain_package('python-neutron-tests')
-        end
-        is_expected.to_not contain_package('python-neutron-vpnaas-tests')
-        is_expected.to_not contain_package('python-neutron-dynamic-routing-tests')
+      it "should install neutron but not *aas tests packages" do
+        is_expected.to contain_package('python-neutron-tests-tempest').with(
+          :name => platform_params[:python_neutron_tests]
+        )
         is_expected.to_not contain_package('python-networking-l2gw-tests-tempest')
       end
     end
+
+    context 'with when managing tests packages for heat (optional service)' do
+      before :each do
+        params.merge!({ :heat_available => true })
+      end
+
+      it "should install heat tests package if available" do
+        is_expected.to contain_package('python-heat-tests-tempest').with(
+          :name => platform_params[:python_heat_tests]
+        )
+      end
+    end
   end
 
   on_supported_os({
@@ -594,13 +572,14 @@ describe 'tempest' do
                                        'libffi-dev',
                                        'patch',
                                        'gcc',
-                                       'python3-virtualenv',
-                                       'python3-pip' ],
+                                       'python3-virtualenv'],
             :package_name          => 'tempest',
             :pip_command           => 'pip3',
+            :pip_package_name      => 'python3-pip',
+            :python_heat_tests     => 'heat-tempest-plugin',
             :python_keystone_tests => 'keystone-tempest-plugin',
             :python_neutron_tests  => 'neutron-tempest-plugin',
-            :python_sahara_tests   => false }
+          }
         when 'RedHat'
           { :dev_packages          => ['python3-devel',
                                        'libxslt-devel',
@@ -611,16 +590,16 @@ describe 'tempest' do
                                        'gcc'],
             :package_name          => 'openstack-tempest',
             :pip_command           => 'pip3',
+            :pip_package_name      => 'python3-pip',
+            :python_heat_tests     => 'python3-heat-tests-tempest',
             :python_keystone_tests => 'python3-keystone-tests-tempest',
             :python_neutron_tests  => 'python3-neutron-tests-tempest',
-            :python_sahara_tests   => 'python3-sahara-tests-tempest' }
+          }
         end
       end
 
       it_behaves_like 'tempest'
-      if facts[:os]['name'] != 'Ubuntu'
-        it_behaves_like 'tempest with plugins packages'
-      end
+      it_behaves_like 'tempest with plugins packages'
     end
   end
 end
